/* tables */
table.tablesorter {
  border-collapse: collapse;
}
table.tablesorter thead tr th,
table.tablesorter tfoot tr th {
  padding: 4px;
  color:#444444;
  border-bottom: 3px solid #E3EAEE;
  color: #444;
  background-color: #f5f5f5;
}
table.tablesorter thead tr .header {
  background-image: url('../images/icons/tablesorter/bg.gif');
  background-repeat: no-repeat;
  background-position: center right;
  cursor: pointer;
  padding-right: 20px;
}
table.tablesorter tbody td {
  border-bottom: 1px solid #E3EAEE;
  background-color: #FFF;
  padding: 0.2em 0.5em;
}
table.tablesorter tbody tr.even td,
table.tablesorter tbody tr.even th {
  background-color:#F7F8F8;
}
table.tablesorter thead tr .headerSortUp {
  background-image: url('../images/icons/tablesorter/asc.gif');
}
table.tablesorter thead tr .headerSortDown {
  background-image: url('../images/icons/tablesorter/desc.gif');
}
table.tablesorter thead tr .headerSortDown, table.tablesorter thead tr .headerSortUp {
  background-color: #E9E9E9;
}

/* table definition. Use together with tablesorter. */

table.definition tbody tr th {
  text-align: right;
  padding: 0.2em 1em;
  border-right: 3px solid #E3EAEE;
  border-bottom: 1px solid #E3EAEE;
}
